Index: package/postgresql/postgresql.mk
===================================================================
--- package/postgresql/postgresql.mk	(revision 0)
+++ package/postgresql/postgresql.mk	(revision 0)
@@ -0,0 +1,66 @@
+#############################################################
+#
+# postgresql
+#
+#############################################################
+POSTGRESQL_VER:=8.4.4
+POSTGRESQL_SOURCE:=postgresql-${POSTGRESQL_VER}.tar.gz
+POSTGRESQL_SITE:=http://wwwmaster.postgresql.org/download/mirrors-ftp/source/v${POSTGRESQL_VER}/
+POSTGRESQL_DIR:=$(BUILD_DIR)/postgresql-${POSTGRESQL_VER}
+POSTGRESQL_CAT:=zcat
+POSTGRESQL_LIBRARY:=src/interfaces/libpq/libpq.so
+POSTGRESQL_TARGET_LIBRARY:=lib/libpq.so
+POSTGRESQL_HEADERS:=src/interfaces/libpq/libpq-fe.h src/include/postgres_ext.h
+
+$(DL_DIR)/$(POSTGRESQL_SOURCE):
+	$(WGET) -P $(DL_DIR) $(POSTGRESQL_SITE)/$(POSTGRESQL_SOURCE)
+
+$(POSTGRESQL_DIR)/.unpacked: $(DL_DIR)/$(POSTGRESQL_SOURCE)
+	$(POSTGRESQL_CAT) $(DL_DIR)/$(POSTGRESQL_SOURCE) | tar -C $(BUILD_DIR) $(TAR_OPTIONS) -
+	toolchain/patch-kernel.sh $(POSTGRESQL_DIR) package/postgresql/ postgresql\*.patch
+	touch $@
+
+$(POSTGRESQL_DIR)/.config_tool_built: $(POSTGRESQL_DIR)/.unpacked
+	(cd $(POSTGRESQL_DIR) ; \
+	./configure --prefix=$(STAGING_DIR) --without-readline --without-zlib )
+	make -C $(POSTGRESQL_DIR) clean
+	make -C $(POSTGRESQL_DIR)/src/bin/pg_config
+	touch $@
+
+$(POSTGRESQL_DIR)/.config_tool: $(POSTGRESQL_DIR)/.config_tool_built
+	install -D $(POSTGRESQL_DIR)/src/bin/pg_config/pg_config $(STAGING_DIR)/bin/pg_config.real
+	( echo "#!/bin/sh" ; echo "$(STAGING_DIR)/bin/pg_config.real \$$@ | sed 's~$(STAGING_DIR)~$(TARGET_DIR)~'" ) > $(STAGING_DIR)/bin/pg_config
+	chmod +x $(STAGING_DIR)/bin/pg_config
+	touch $@
+
+$(POSTGRESQL_DIR)/$(POSTGRESQL_LIBRARY): $(POSTGRESQL_DIR)/.config_tool
+	(cd $(POSTGRESQL_DIR) ; \
+	make clean ; \
+	PATH=$(STAGING_DIR)/bin:$$PATH ./configure --host=${REAL_GNU_TARGET_NAME} --build=${GNU_HOST_NAME} --prefix=/usr \
+	--without-readline --without-zlib ; \
+	PATH=$(STAGING_DIR)/bin:$$PATH $(MAKE) -C src/interfaces/libpq ; \
+	PATH=$(STAGING_DIR)/bin:$$PATH ./configure --host=${REAL_GNU_TARGET_NAME} --build=${GNU_HOST_NAME} --prefix=$(TARGET_DIR) --without-readline --without-zlib )
+
+$(TARGET_DIR)/$(POSTGRESQL_TARGET_LIBRARY): $(POSTGRESQL_DIR)/$(POSTGRESQL_LIBRARY)
+	PATH=$(STAGING_DIR)/bin:$$PATH $(MAKE) -C $(POSTGRESQL_DIR)/src/interfaces/libpq install
+	PATH=$(STAGING_DIR)/bin:$$PATH $(MAKE) -C $(POSTGRESQL_DIR)/src/backend ../../src/include/utils/fmgroids.h
+	PATH=$(STAGING_DIR)/bin:$$PATH $(MAKE) -C $(POSTGRESQL_DIR)/src/include install
+
+postgresql: $(TARGET_DIR)/$(POSTGRESQL_TARGET_LIBRARY)
+
+postgresql-clean:
+	rm -f $(TARGET_DIR)/$(POSTGRESQL_TARGET_BINARY)
+	rm -f $(STAGING_DIR)/bin/pg_config
+	-$(MAKE) -C $(POSTGRESQL_DIR) clean
+
+postgresql-dirclean:
+	rm -rf $(POSTGRESQL_DIR)
+
+#############################################################
+#
+# Toplevel Makefile options
+#
+#############################################################
+ifeq ($(strip $(BR2_PACKAGE_POSTGRESQL)),y)
+TARGETS+=postgresql
+endif
Index: package/postgresql/Config.in
===================================================================
--- package/postgresql/Config.in	(revision 0)
+++ package/postgresql/Config.in	(revision 0)
@@ -0,0 +1,7 @@
+config BR2_PACKAGE_POSTGRESQL
+	bool "postgresql"
+	default y
+	help
+	  The standard database.
+
+	  http://www.postgresql.org
Index: package/Config.in
===================================================================
--- package/Config.in	(revision 4225)
+++ package/Config.in	(working copy)
@@ -187,6 +187,7 @@
 source "package/php5/Config.in"
 source "package/portage/Config.in"
 source "package/portmap/Config.in"
+source "package/postgresql/Config.in"
 source "package/pppd/Config.in"
 source "package/pptpd/Config.in"
 source "package/procps/Config.in"
